Gemeinde Adressverwaltung GUI: Elementverzeichnis

Gemeinde Adressverwaltung GUI

Gemeinde_Modelle.JobsSchlank Elementverzeichnis

Vollständige Aufstellung aller Elemente für Gemeinde_Modelle.JobsSchlank einschließlich aller geerbten Elemente.

__init__(self, id=None, holen=False) (Definiert in Gemeinde_Modelle.JobsSchlank) | Gemeinde_Modelle.JobsSchlank |
__str__(self) (Definiert in Gemeinde_Modelle.JobsSchlank) | Gemeinde_Modelle.JobsSchlank |
keyFeldNavi (Definiert in Gemeinde_Modelle.JobsSchlank) | Gemeinde_Modelle.JobsSchlank | static